@@ -5,22 +5,25 @@ from __future__ import annotations
 import base64
 import datetime
 import io
-import sys
 from dataclasses import dataclass
-from os import PathLike
 from pathlib import Path
-from types import TracebackType
-from typing import Any, BinaryIO, Generator, Iterable, Mapping, Sequence, TypeVar
+from typing import TYPE_CHECKING, TypeVar
 
 import requests
 
 from citric import enums
 from citric.session import Session
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+if TYPE_CHECKING:
+    import sys
+    from os import PathLike
+    from types import TracebackType
+    from typing import Any, BinaryIO, Generator, Iterable, Mapping, Sequence
+
+    if sys.version_info >= (3, 8):
+        from typing import Literal
+    else:
+        from typing_extensions import Literal
 
 
 _T = TypeVar("_T", bound="Client")
@@ -131,9 +134,9 @@ class Client:
 
     def __exit__(
         self,
-        exc_type: type[BaseException] | None,  # noqa: ARG002
-        exc_value: BaseException | None,  # noqa: ARG002
-        traceback: TracebackType | None,  # noqa: ARG002
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        traceback: TracebackType | None,
     ) -> None:
         """Safely exit the client context."""
         self.close()
@@ -283,7 +286,7 @@ class Client:
         response_data: Mapping[str, Any],
         question_mapping: dict[str, dict[str, Any]],
     ) -> dict[str, Any]:
-        """Converts response keys to LimeSurvey's internal representation.
+        """Convert response keys to LimeSurvey's internal representation.
 
         Args:
             response_data: The response mapping.
@@ -568,7 +571,7 @@ class Client:
         Returns:
             Bytes length written to file.
         """
-        with open(filename, "wb") as f:
+        with Path(filename).open("wb") as f:
             return f.write(
                 self.export_responses(
                     survey_id,
@@ -581,7 +584,7 @@ class Client:
                     from_response_id=from_response_id,
                     to_response_id=to_response_id,
                     fields=fields,
-                )
+                ),
             )
 
     def export_statistics(
@@ -614,7 +617,7 @@ class Client:
                 language,
                 "yes" if graph else "no",
                 group_ids,
-            )
+            ),
         )
 
     def save_statistics(
@@ -642,7 +645,7 @@ class Client:
         Returns:
             Bytes length written to file.
         """
-        with open(filename, "wb") as f:
+        with Path(filename).open("wb") as f:
             return f.write(
                 self.export_statistics(
                     survey_id,
@@ -650,7 +653,7 @@ class Client:
                     language=language,
                     graph=graph,
                     group_ids=group_ids,
-                )
+                ),
             )
 
     def export_timeline(
@@ -675,7 +678,9 @@ class Client:
             survey_id,
             enums.TimelineAggregationPeriod(period),
             start.isoformat(),
-            end.isoformat() if end else datetime.datetime.utcnow().isoformat(),
+            end.isoformat()
+            if end
+            else datetime.datetime.now(tz=datetime.timezone.utc).isoformat(),
         )
 
     def get_group_properties(
@@ -922,7 +927,7 @@ class Client:
         for file in uploaded_files:
             filepath = dirpath / file.meta.filename
             filepaths.append(filepath)
-            with open(filepath, "wb") as f:
+            with Path(filepath).open("wb") as f:
                 f.write(file.content.read())
 
         return filepaths
@@ -1241,5 +1246,5 @@ class Client:
         if filename is None:
             filename = path.name
 
-        with open(path, "rb") as file:
+        with Path(path).open("rb") as file:
             return self.upload_file_object(survey_id, field, filename, file)
