@@ -4,19 +4,23 @@ from __future__ import annotations
 
 import logging
 import random
-from types import TracebackType
-from typing import Any, TypeVar
+from typing import TYPE_CHECKING, TypeVar
 
 import requests
 
 from citric.exceptions import (
     LimeSurveyApiError,
-    LimeSurveyError,
     LimeSurveyStatusError,
     ResponseMismatchError,
+    RPCInterfaceNotEnabledError,
 )
 from citric.method import Method
 
+if TYPE_CHECKING:
+    from types import TracebackType
+    from typing import Any
+
+GET_SESSION_KEY = "get_session_key"
 _T = TypeVar("_T", bound="Session")
 logger = logging.getLogger(__name__)
 
@@ -100,7 +104,7 @@ class Session:
         Returns:
             An RPC result.
         """
-        if method == "get_session_key" or method.startswith("system."):
+        if method == GET_SESSION_KEY or method.startswith("system."):
             return self._invoke(self._session, self.url, method, *params)
 
         # Methods requiring authentication
@@ -126,8 +130,9 @@ class Session:
             LimeSurveyStatusError: The response key from the response payload has
                 a non-null status.
             LimeSurveyApiError: The response payload has a non-null error key.
-            LimeSurveyError: If the JSON RPC interface is not enabled (empty response).
             ResponseMismatchError: Request ID does not match the response ID.
+            RPCInterfaceNotEnabledError: If the JSON RPC interface is not enabled
+                (empty response).
 
         Returns:
             Any: An RPC result.
@@ -144,7 +149,7 @@ class Session:
         res.raise_for_status()
 
         if res.text == "":
-            raise LimeSurveyError("RPC interface not enabled")
+            raise RPCInterfaceNotEnabledError
 
         data = res.json()
 
@@ -186,9 +191,9 @@ class Session:
 
     def __exit__(
         self,
-        exc_type: type[BaseException] | None,  # noqa: ARG002
-        exc_value: BaseException | None,  # noqa: ARG002
-        traceback: TracebackType | None,  # noqa: ARG002
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        traceback: TracebackType | None,
     ) -> None:
         """Safely exit an RPC session.
 
